@@ -13,10 +13,12 @@ TEST_DIR_WIS_CONFIG = TEST_INPUT_DIR / "config_wis60prd_202002"
 TEST_PATH_STARTENDDATE_CAW_OPP_SHORT = TEST_INPUT_DIR / "startenddate" / "caw_oppervlaktewater_short.csv"
 TEST_DIR_PD_FLEX_READ_CSV = TEST_INPUT_DIR / "pd_read_flex_csv"
 
+PANDAS_DEFAULT_QUOTECHAR = '"'  # pd.read_csv(quotechar='"')
+
 # Github wis mpt config repo (only for testing)
 GITHUB_ORGANISATION_NAME = "hdsr-mid"
 GITHUB_WIS_CONFIG_REPO_NAME = "FEWS-WIS_HKV"
-GITHUB_WIS_CONFIG_BRANCH_NAME = "202002-prd"
+GITHUB_WIS_CONFIG_BRANCH_NAME = "productie"
 
 # Github startendate repo
 GITHUB_STARTENDDATE_REPO_NAME = "startenddate"
