@@ -116,10 +116,13 @@ class LocationMapper:
     def complex_to_hoofd(self, caw_complex: str) -> List[str]:
         """Retrieve all related hoofd locations on this caw complex"""
         self._validate_caw_complex(caw_complex=caw_complex)
-        df_idmap_filtered = self.df_idmap.get_filtered_df(ex_loc=caw_complex)
-        assert not df_idmap_filtered.empty, f"caw_complex (ex_loc) {caw_complex} not in idmapping"
-        hoofd_locs = [x for x in df_idmap_filtered[IdMapCols.int_loc].unique() if IntLocChoices.is_kw_hoofd(int_loc=x)]
-        hoofd_locs = list(set(hoofd_locs))
+        df_idmap_filtered_normal = self.df_idmap.get_filtered_df(ex_loc=caw_complex)
+        df_idmap_filtered_str = self.df_idmap[self.df_idmap[IdMapCols.int_loc].str.contains(f"KW{caw_complex}")]
+        df_merge = pd.concat(objs=[df_idmap_filtered_normal, df_idmap_filtered_str], axis=0)
+        if df_merge.empty:
+            msg = f"caw_complex {caw_complex} not in idmapping (expected KW{caw_complex} in column {IdMapCols.int_loc}"
+            raise AssertionError(msg)
+        hoofd_locs = [x for x in df_merge[IdMapCols.int_loc].unique() if IntLocChoices.is_kw_hoofd(int_loc=x)]
         hoofd_locs_less_simple = []
         for hoofd_loc in hoofd_locs:
             _caw_complex = hoofd_loc[0:6]
