@@ -7,14 +7,14 @@ from typing import Union
 
 class XmlReader:
     @classmethod
-    def __xml_to_etree(cls, xml_filepath: Path) -> ET._Element:
+    def _xml_to_etree(cls, xml_filepath: Path) -> ET._Element:
         """Parses an xml-file to an etree. ETree can be used in function etree_to_dict"""
         assert isinstance(xml_filepath, Path), f"path {xml_filepath} must be a pathlib.Path"
         etree = ET.parse(source=xml_filepath.as_posix()).getroot()
         return etree
 
     @classmethod
-    def __etree_to_dict(
+    def _etree_to_dict(
         cls, etree: Union[ET._Element, ET._Comment], section_start: str = None, section_end: str = None,
     ) -> Dict:
         """converts an etree to a dictionary"""
@@ -54,7 +54,7 @@ class XmlReader:
         if children:
             dd = defaultdict(list)
             # for dc in map(etree_to_dict, children):
-            for dc in [cls.__etree_to_dict(etree=child) for child in children]:
+            for dc in [cls._etree_to_dict(etree=child) for child in children]:
                 for k, v in dc.items():
                     dd[k].append(v)
 
@@ -73,6 +73,6 @@ class XmlReader:
     @classmethod
     def xml_to_dict(cls, xml_filepath: Path, section_start: str = None, section_end: str = None) -> Dict:
         """Convert an xml-file to a dictionary"""
-        etree = cls.__xml_to_etree(xml_filepath=xml_filepath)
-        _dict = cls.__etree_to_dict(etree=etree, section_start=section_start, section_end=section_end)
+        etree = cls._xml_to_etree(xml_filepath=xml_filepath)
+        _dict = cls._etree_to_dict(etree=etree, section_start=section_start, section_end=section_end)
         return _dict
