@@ -3,7 +3,7 @@ from hdsr_wis_config_reader.constants import TEST_DIR_WIS_CONFIG
 from hdsr_wis_config_reader.idmappings.columns import IdMapCols
 from hdsr_wis_config_reader.idmappings.files import IdMapChoices
 from hdsr_wis_config_reader.tests.fixtures import fews_config_local
-from hdsr_wis_config_reader.tests.helpers import is_equal_dataframes
+from hdsr_wis_config_reader.utils import DataframeActions
 
 import pandas as pd  # noqa pandas comes with geopandas
 
@@ -57,7 +57,7 @@ def test_idmapping_opvl_water(fews_config_local):
     df_idmap_opvl_water = id_mappings.idmap_opvl_water.get_filtered_df(int_loc="KW761001")
     assert isinstance(df_idmap_opvl_water, pd.DataFrame)
     assert len(df_idmap_opvl_water) == 2
-    assert is_equal_dataframes(expected_df=expected_df_a, test_df=df_idmap_opvl_water)
+    assert DataframeActions.is_equal_dataframes(df1=expected_df_a, df2=df_idmap_opvl_water)
 
     ex_par_values = id_mappings.idmap_grondwater_caw.get_filtered_column_values(
         make_result_unique=True, target_column=IdMapCols.ex_par,
@@ -67,7 +67,7 @@ def test_idmapping_opvl_water(fews_config_local):
     df_all = id_mappings.idmap_all.get_filtered_df(int_loc="KW761001")
     assert isinstance(df_all, pd.DataFrame)
     assert len(df_all) == 3
-    assert is_equal_dataframes(expected_df=expected_df_b, test_df=df_all)
+    assert DataframeActions.is_equal_dataframes(df1=expected_df_b, df2=df_all)
 
 
 def test_read_idmap_oppvl(fews_config_local):
@@ -80,7 +80,7 @@ def test_read_idmap_oppvl(fews_config_local):
     # read same idmap but now via fews config
     collection = IdMappingCollection(fews_config=fews_config_local)
     df_oppvl_with_fews = collection.get_idmap_df_via_choice(IdMapChoices.idmap_opvl_water)
-    assert is_equal_dataframes(expected_df=df_oppvl_without_fews, test_df=df_oppvl_with_fews)
+    assert DataframeActions.is_equal_dataframes(df1=df_oppvl_without_fews, df2=df_oppvl_with_fews)
 
 
 def test_read_idmap_oppvl_hymos(fews_config_local):
@@ -92,4 +92,4 @@ def test_read_idmap_oppvl_hymos(fews_config_local):
     # read same idmap but now via fews config
     collection = IdMappingCollection(fews_config=fews_config_local)
     df_oppvl_hymos_with_fews = collection.get_idmap_df_via_choice(IdMapChoices.idmap_opvl_water_hymos)
-    assert is_equal_dataframes(expected_df=df_oppvl_hymos_without_fews, test_df=df_oppvl_hymos_with_fews)
+    assert DataframeActions.is_equal_dataframes(df1=df_oppvl_hymos_without_fews, df2=df_oppvl_hymos_with_fews)
