@@ -29,7 +29,9 @@ def test_merge_github_startenddate_local_idmapping(fews_config_local):
     id_mappings = IdMappingCollection(fews_config=fews_config_local)
 
     target_file = Path("data/output/results/caw_oppervlaktewater_short.csv")
-    startenddate_github = StartEndDateReaderGithub(target_file=target_file)
+    startenddate_github = StartEndDateReaderGithub(
+        target_file=target_file, allowed_period_no_updates=timedelta(weeks=52)
+    )
     df_startenddate = startenddate_github.df_startenddate
 
     df = merge_startenddate_idmap(df_idmap=id_mappings.idmap_opvl_water, df_startenddate=df_startenddate)
@@ -44,7 +46,7 @@ def test_github_startenddate_too_old():
         df = startenddate_github.df_startenddate  # noqa
 
 
-def test_xx(fews_config_local):
+def test_github_startenddate_ok(fews_config_local):
     id_map_collection = IdMappingCollection(fews_config=fews_config_local)
     df = merge_startenddate_github_with_idmap(df_idmap=id_map_collection.idmap_all)
     assert isinstance(df, pd.DataFrame)
